Documentation
¶
Index ¶
- Constants
- func NewPool(n, bufSize int) *pool
- type HTTPListener
- func (h *HTTPListener) AuthenticateIfSet(handler http.HandlerFunc, res http.ResponseWriter, req *http.Request)
- func (h *HTTPListener) Description() string
- func (h *HTTPListener) Gather(_ telegraf.Accumulator) error
- func (h *HTTPListener) SampleConfig() string
- func (h *HTTPListener) ServeHTTP(res http.ResponseWriter, req *http.Request)
- func (h *HTTPListener) Start(acc telegraf.Accumulator) error
- func (h *HTTPListener) Stop()
- type TimeFunc
Constants ¶
const ( // DEFAULT_MAX_BODY_SIZE is the default maximum request body size, in bytes. // if the request body is over this size, we will return an HTTP 413 error. // 500 MB DEFAULT_MAX_BODY_SIZE = 500 * 1024 * 1024 // MAX_LINE_SIZE is the maximum size, in bytes, that can be allocated for // a single InfluxDB point. // 64 KB DEFAULT_MAX_LINE_SIZE = 64 * 1024 )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type HTTPListener ¶
type HTTPListener struct {
ServiceAddress string
ReadTimeout internal.Duration
WriteTimeout internal.Duration
MaxBodySize int64
MaxLineSize int
Port int
tlsint.ServerConfig
BasicUsername string
BasicPassword string
TimeFunc
BytesRecv selfstat.Stat
RequestsServed selfstat.Stat
WritesServed selfstat.Stat
QueriesServed selfstat.Stat
PingsServed selfstat.Stat
RequestsRecv selfstat.Stat
WritesRecv selfstat.Stat
QueriesRecv selfstat.Stat
PingsRecv selfstat.Stat
NotFoundsServed selfstat.Stat
BuffersCreated selfstat.Stat
AuthFailures selfstat.Stat
// contains filtered or unexported fields
}
func (*HTTPListener) AuthenticateIfSet ¶
func (h *HTTPListener) AuthenticateIfSet(handler http.HandlerFunc, res http.ResponseWriter, req *http.Request)
func (*HTTPListener) Description ¶
func (h *HTTPListener) Description() string
func (*HTTPListener) Gather ¶
func (h *HTTPListener) Gather(_ telegraf.Accumulator) error
func (*HTTPListener) SampleConfig ¶
func (h *HTTPListener) SampleConfig() string
func (*HTTPListener) ServeHTTP ¶
func (h *HTTPListener) ServeHTTP(res http.ResponseWriter, req *http.Request)
func (*HTTPListener) Start ¶
func (h *HTTPListener) Start(acc telegraf.Accumulator) error
Start starts the http listener service.
Click to show internal directories.
Click to hide internal directories.